@@ -1,6 +1,6 @@
 ##' monthly download stats of cran package(s)
 ##'
-##' 
+##'
 ##' @title cran_stats
 ##' @param packages packages
 ##' @return data.frame
@@ -21,16 +21,16 @@ cran_stats <- function(packages) {
     if (length(packages) == 0) {
         return(stats_cache)
     }
-    
+
     pkgs <- paste(packages, sep = ',', collapse = ',')
     year <- get_start_year(pkgs)
-    
+
     start <- as.Date(paste0(year, "-01-01"))
     end <- as.Date(format(Sys.time(), "%Y-%m-%d"))
-    
+
     all_months <- seq(start, end, by = 'month')
     n <- length(all_months)
-    
+
     urls <- sapply(seq_along(all_months), function(i) {
         mstart <- all_months[i]
         if (i == n) {
@@ -38,13 +38,13 @@ cran_stats <- function(packages) {
         } else {
             mend <- all_months[i+1]-1
         }
-        
-        paste0("http://cranlogs.r-pkg.org/downloads/total/",
+
+        paste0("https://cranlogs.r-pkg.org/downloads/total/",
                mstart, ":", mend, "/", pkgs)
     })
 
     stats <- lapply(urls, function(url) fromJSON(suppressWarnings(readLines(url)))) %>% do.call('rbind', .)
-    
+
     ## stats$downloads %<>% as.numeric
     stats <- stats[stats$downloads != 0,]
     res <- setup_stats(stats, packages)
@@ -67,7 +67,7 @@ get_start_year <- function(pkg) {
     start_year <- 2012
     end_year <- format(Sys.time(), "%Y") %>% as.numeric
     for (year in start_year:end_year) {
-        url <- paste0("http://cranlogs.r-pkg.org/downloads/total/",
+        url <- paste0("https://cranlogs.r-pkg.org/downloads/total/",
                       year, "-01-01:", year, "-12-31/", pkg)
         d <- fromJSON(suppressWarnings(readLines(url)))
         if (any(d$downloads > 0)) {
@@ -79,25 +79,25 @@ get_start_year <- function(pkg) {
 
 get_start_year2 <- function(pkg) {
     left <- 2012
-    right <- format(Sys.time(), "%Y") %>% as.numeric 
+    right <- format(Sys.time(), "%Y") %>% as.numeric
     m = ceiling((right-left)/2)
-    
+
     while(m > 0) {
         years <- seq(left, right)
     	year = years[m]
-        
+
         url <- paste0("http://cranlogs.r-pkg.org/downloads/total/",
                       year, "-01-01:", year, "-12-31/", pkg)
         d <- suppressWarnings(fromJSON(readLines(url)))
-        
+
         if (d$downloads == 0) {
             left = year + 1
         } else {
             right = year
         }
-        m = right - left			
+        m = right - left
     }
-    return(right)    
+    return(right)
 }
 
 
@@ -105,7 +105,7 @@ get_start_year2 <- function(pkg) {
 parseJSON <- function(x) {
     xx <- unlist(strsplit(x, ',')) %>% strsplit(., ':') %>% do.call('cbind', .)
     yy <- apply(xx, 2, function(x) gsub("^[^0-9A-Za-z]+([0-9A-Za-z\\-]+)[^0-9A-Za-z]+$", '\\1', x))
-    
+
     colnames(yy) = yy[1,]
     yy = as.data.frame(yy, stringsAsFactors=FALSE)
     yy <- yy[-1,, drop=FALSE]
